<?php
$parameters = array(
	'db_driver' => 'pdo_mysql',
	'db_host' => 'mautic-db',
	'db_port' => '3306',
	'db_name' => 'mautic',
	'db_user' => 'mautic',
	'db_password' => 'LpSgxWGNzQZPCUjkWHIiYwmAasGUwuLd',
	'db_table_prefix' => null,
	'db_backup_tables' => 1,
	'db_backup_prefix' => 'bak_',
	'db_host_ro' => null,
	'secret_key' => '9ec6f90af44e6acaa0dab4f7ddcfb7d63fe366d85a3ac1f7456b498d3ac6212d',
	'site_url' => 'http://mautic.heckenfels.com',
);
